@@ -12,8 +12,8 @@
 
 #include <KCalendarCore/ICalFormat>
 #include <KCalendarCore/ScheduleMessage>
-#include <identity.h>
-#include <identitymanager.h>
+#include <KIdentityManagement/Identity>
+#include <KIdentityManagement/IdentityManager>
 
 #include <KLocalizedString>
 #include <QStandardPaths>
@@ -24,7 +24,7 @@ using namespace KIdentityManagement;
 class Akonadi::MailSchedulerPrivate
 {
 public:
-    KIdentityManagement::Identity identityForIncidence(const KCalendarCore::IncidenceBase::Ptr &incidence) const;
+    Q_REQUIRED_RESULT KIdentityManagement::Identity identityForIncidence(const KCalendarCore::IncidenceBase::Ptr &incidence) const;
 
     KIdentityManagement::IdentityManager *m_identityManager = nullptr;
     MailClient *m_mailer = nullptr;
